var weatherdata;

var rawWeatherData = '{"coord":{"lon":-104.98,"lat":39.74},"weather":[{"id":801,"main":"Clouds","description":"few clouds","icon":"02d"}],"base":"cmc stations","main":{"temp":300.56,"pressure":1028,"humidity":39,"temp_min":298.25,"temp_max":303.15},"wind":{"speed":2.6,"deg":230},"clouds":{"all":20},"dt":1439570431,"sys":{"type":1,"id":546,"message":0.014,"country":"US","sunrise":1439554293,"sunset":1439603803},"id":5419384,"name":"Denver","cod":200}';

exports.setUp = function(callback) {
  weatherdata = {}
  weatherdata.__proto__ = require('../../models/weatherdata.js');
  callback();
}

exports.testCanary = function(test) {
  test.ok(true);
  test.done();
}

var checkAlmostEqual = function(test, expected, actual) {
  var failureMessage = expected + ' is not almost equal to ' + actual;
  test.ok(Math.abs(expected - actual) < 0.001, failureMessage);
}

exports.test100K2F= function(test) {
  checkAlmostEqual(test, -279.67, weatherdata.k2f(100));
  test.done();
}

exports.test0K2F= function(test) {
  checkAlmostEqual(test, -459.67, weatherdata.k2f(0));
  test.done();
}

exports.testGetWeatherData = function(test) {
  var callback = function(data) {
    test.ok(data.indexOf('temp') > 0);
    test.ok(data.indexOf('Denver') > 0);
    test.done();
  }
  
  var lat = 39.73;
  var lon = -104.99;
  weatherdata.getWeatherData(lat, lon, callback);
}

exports.testParseWeatherData = function(test) {
  var weatherData = weatherdata.parseWeatherData(rawWeatherData);

  checkAlmostEqual(test, 81.338, weatherData.temperature);
  test.equals("few clouds", weatherData.condition);
  test.done(); 
}

exports.testWeatherCallsGetWeatherData = function(test) {
  var req = {
    query: {lat: 39, lon: -149}
  };
  var res;

  var sampleData = 'sampleData';
  
  weatherdata.sendWeatherData = function(res, data) {
      test.equal(data, sampleData);
      test.done();
  }
  
  weatherdata.getWeatherData = function(lat, lon, callback) {
    test.equal(req.query.lat, lat);
    test.equal(req.query.lon, lon);
    callback(sampleData);
  }
  
  weatherdata.weather(req, res);
}

exports.testSendWeatherDataCallsParseDataAndJson = function(test) {
  var sampleData = "sampleData";
  var res = { json: function(data) {
    test.equal(sampleData, data);
    test.done();
  }};
  
  weatherdata.parseWeatherData = function(rawData) { return sampleData; }
  
  weatherdata.sendWeatherData(res, rawWeatherData);
}
